
//
//	hsp3code.cpp header
//
#ifndef __hsp3jit_h
#define __hsp3jit_h

#include "hsp3debug.h"
#include "hsp3struct.h"

//extern PVal *g_mpval;

void jit_init( void );
void jit_bye( void );
void jit_termfunc( void );
void jit_setctx( HSPCTX *ctx );
void jit_resetctx( HSPCTX *ctx );
void jit_setpc( const unsigned short *pc );
void jit_setpci( const unsigned short *pc );
void jit_call( const unsigned short *pc );

int jit_execcmd( void );
int jit_execcmd2( void );
int jit_exec_wait( int tick );
int jit_exec_await( int tick );

HSPERROR jit_geterror( void );
void jit_puterror( HSPERROR error );

void jit_next( void );
int jit_get( void );
int jit_getexflg( void );

char *jit_gets( void );
char *jit_getds( const char *defval );
char *jit_getdsi( const char *defval );
int jit_geti( void );
int jit_getdi( const int defval );
double jit_getd( void );
double jit_getdd( const double defval );
PVal *jit_getpval( void );
char *jit_getvptr( PVal **pval, int *size );

APTR jit_getva( PVal **pval );
void jit_setva( PVal *pval, APTR aptr, int type, const void *ptr );
//PDAT *jit_getv( PVal **pval );
//void jit_setv( PVal *pval, PDAT *dat, int type, void *ptr );

unsigned short *jit_getlb( void );
unsigned short *jit_getlb2( void );

STRUCTDAT *jit_getstruct( void );
STRUCTPRM *jit_getstprm( void );
STRUCTDAT *jit_getcomst( void );
char *jit_get_proxyvar( char *ptr, int *mptype );
APTR jit_getv_proxy( PVal **pval, MPVarData *var, int mptype );

#define CODE_EXPANDSTRUCT_OPT_NONE 0
#define CODE_EXPANDSTRUCT_OPT_LOCALVAR 1

void jit_expandstruct( char *p, STRUCTDAT *st, int option );
void jit_setvs( PVal *pval, APTR aptr, int type, void *ptr, int size, int subid );

char *jit_stmpstr( char *src );
char *jit_stmp( int size );
char *jit_getsptr( int *type );

int jit_debug_init( void );
int jit_getdebug_line( void );
char *jit_getdebug_name( void );
int jit_getdebug_seekvar( const char *name );
char *jit_getdebug_varname( int val_id );

int jit_event( int event, int prm1, int prm2, void *prm3 );
void jit_bload( char *fname, int ofs, int size, void *ptr );
void jit_bsave( char *fname, int ofs, int size, void *ptr );

IRQDAT *jit_getirq( int id );
IRQDAT *jit_seekirq( int actid, int custom );
IRQDAT *jit_addirq( void );
int jit_isirq( int id );
int jit_isuserirq( void );
int jit_sendirq( int id, int iparam, int wparam, int lparam );
int jit_checkirq( int id, int message, int wparam, int lparam );
void jit_execirq( IRQDAT *irq, int wparam, int lparam );
void jit_setirq( int id, int opt, int custom, unsigned short *ptr );
int jit_irqresult( int *value );
void jit_enableirq( int id, int sw );

HSP3TYPEINFO *jit_gettypeinfo( int type );
void jit_enable_typeinfo( HSP3TYPEINFO *info );

HSP3DEBUG *jit_getdbg( void );
char *jit_inidbg( void );
void jit_adddbg( char *name, int val );
void jit_adddbg( char *name, char *str );

void jit_dbg_global( void );
char *jit_dbgvalue( int type );
char *jit_dbgvarinf( char *target, int option );
void jit_dbgcurinf( void );
void jit_dbgclose( char *buf );
int jit_dbgset( int id );
void jit_dbgtrace( void );

void jit_delstruct( PVal *in_pval, APTR in_aptr );
void jit_delstruct_all( PVal *pval );


#endif
